==> nvidia-cuda-toolkit_12.2.0.orig-ppc64el.tar.xz: nvidia-cuda-toolkit-12.2.0.orig-ppc64el/cuda_sanitizer_api/compute-sanitizer/docs/search/htmlFileList.js <==
//List of files which are indexed.
fl = new Array();
fl["0"]= "ComputeSanitizer/index.html";
fl["1"]= "CopyrightAndLicenses/index.html";
fl["2"]= "ReleaseNotes/index.html";
fl["3"]= "SanitizerApi/annotated.html";
fl["4"]= "SanitizerApi/classes.html";
fl["5"]= "SanitizerApi/functions.html";
fl["6"]= "SanitizerApi/functions_vars.html";
fl["7"]= "SanitizerApi/group__SANITIZER__BARRIER__API.html";
fl["8"]= "SanitizerApi/group__SANITIZER__CALLBACK__API.html";
fl["9"]= "SanitizerApi/group__SANITIZER__MEMORY__API.html";
fl["10"]= "SanitizerApi/group__SANITIZER__PATCHING__API.html";
fl["11"]= "SanitizerApi/group__SANITIZER__RESULT__API.html";
fl["12"]= "SanitizerApi/group__SANITIZER__STREAM__API.html";
fl["13"]= "SanitizerApi/index.html";
fl["14"]= "SanitizerApi/modules.html";
fl["15"]= "SanitizerApi/notices-header.html";
fl["16"]= "SanitizerApi/structSanitizer__BatchMemopData.html";
fl["17"]= "SanitizerApi/structSanitizer__CallbackData.html";
fl["18"]= "SanitizerApi/structSanitizer__EventData.html";
fl["19"]= "SanitizerApi/structSanitizer__ExternalMemoryData.html";
fl["20"]= "SanitizerApi/structSanitizer__GraphExecData.html";
fl["21"]= "SanitizerApi/structSanitizer__GraphLaunchData.html";
fl["22"]= "SanitizerApi/structSanitizer__GraphNodeLaunchData.html";
fl["23"]= "SanitizerApi/structSanitizer__LaunchData.html";
fl["24"]= "SanitizerApi/structSanitizer__MemcpyData.html";
fl["25"]= "SanitizerApi/structSanitizer__MemsetData.html";
fl["26"]= "SanitizerApi/structSanitizer__ResourceArrayData.html";
fl["27"]= "SanitizerApi/structSanitizer__ResourceContextData.html";
fl["28"]= "SanitizerApi/structSanitizer__ResourceFunctionsLazyLoadedData.html";
fl["29"]= "SanitizerApi/structSanitizer__ResourceMemoryData.html";
fl["30"]= "SanitizerApi/structSanitizer__ResourceMempoolData.html";
fl["31"]= "SanitizerApi/structSanitizer__ResourceModuleData.html";
fl["32"]= "SanitizerApi/structSanitizer__ResourceStreamData.html";
fl["33"]= "SanitizerApi/structSanitizer__SynchronizeData.html";
fl["34"]= "SanitizerApi/structSanitizer__UvmData.html";
fl["35"]= "SanitizerApiGuide/index.html";
fl["36"]= "SanitizerNvtxGuide/index.html";
var doStem = true

==> nvidia-cuda-toolkit_12.4.1.orig-ppc64el.tar.xz: nvidia-cuda-toolkit-12.4.1.orig-ppc64el/cuda_sanitizer_api/compute-sanitizer/docs/search/htmlFileList.js <==
//List of files which are indexed.
fl = new Array();
fl["0"]= "ComputeSanitizer/index.html";
fl["1"]= "CopyrightAndLicenses/index.html";
fl["2"]= "ReleaseNotes/index.html";
fl["3"]= "SanitizerApi/annotated.html";
fl["4"]= "SanitizerApi/classes.html";
fl["5"]= "SanitizerApi/functions.html";
fl["6"]= "SanitizerApi/functions_vars.html";
fl["7"]= "SanitizerApi/group__SANITIZER__BARRIER__API.html";
fl["8"]= "SanitizerApi/group__SANITIZER__CALLBACK__API.html";
fl["9"]= "SanitizerApi/group__SANITIZER__MEMORY__API.html";
fl["10"]= "SanitizerApi/group__SANITIZER__PATCHING__API.html";
fl["11"]= "SanitizerApi/group__SANITIZER__RESULT__API.html";
fl["12"]= "SanitizerApi/group__SANITIZER__STREAM__API.html";
fl["13"]= "SanitizerApi/index.html";
fl["14"]= "SanitizerApi/modules.html";
fl["15"]= "SanitizerApi/notices-header.html";
fl["16"]= "SanitizerApi/structSanitizer__BatchMemopData.html";
fl["17"]= "SanitizerApi/structSanitizer__CallbackData.html";
fl["18"]= "SanitizerApi/structSanitizer__EventData.html";
fl["19"]= "SanitizerApi/structSanitizer__ExternalMemoryData.html";
fl["20"]= "SanitizerApi/structSanitizer__GraphExecData.html";
fl["21"]= "SanitizerApi/structSanitizer__GraphLaunchData.html";
fl["22"]= "SanitizerApi/structSanitizer__GraphNodeLaunchData.html";
fl["23"]= "SanitizerApi/structSanitizer__LaunchData.html";
fl["24"]= "SanitizerApi/structSanitizer__MemcpyData.html";
fl["25"]= "SanitizerApi/structSanitizer__MemsetData.html";
fl["26"]= "SanitizerApi/structSanitizer__ResourceArrayData.html";
fl["27"]= "SanitizerApi/structSanitizer__ResourceContextData.html";
fl["28"]= "SanitizerApi/structSanitizer__ResourceFunctionsLazyLoadedData.html";
fl["29"]= "SanitizerApi/structSanitizer__ResourceMemoryData.html";
fl["30"]= "SanitizerApi/structSanitizer__ResourceMempoolData.html";
fl["31"]= "SanitizerApi/structSanitizer__ResourceModuleData.html";
fl["32"]= "SanitizerApi/structSanitizer__ResourceStreamData.html";
fl["33"]= "SanitizerApi/structSanitizer__ResourceVirtualRange.html";
fl["34"]= "SanitizerApi/structSanitizer__SynchronizeData.html";
fl["35"]= "SanitizerApi/structSanitizer__UvmData.html";
fl["36"]= "SanitizerApiGuide/index.html";
fl["37"]= "SanitizerNvtxGuide/index.html";
var doStem = true
